
package Paws::ELB::CreateLoadBalancerPolicyOutput;
  use Moose;

1;

### main pod documentation begin ###

=head1 NAME

Paws::ELB::CreateLoadBalancerPolicyOutput

=head1 ATTRIBUTES



=cut

